@@ -1,3 +1,4 @@
-from .exc import Flexihash_Exception
-from .crc32 import Flexihash_Crc32Hasher
 from .flexihash import Flexihash
+from .exc import Flexihash_Exception
+from .crc32 import Crc32Hasher
+from .md5 import Md5Hasher
