@@ -1,5 +1,6 @@
 import zlib
 
-class Flexihash_Crc32Hasher(object):
+
+class Crc32Hasher(object):
     def hash(self, value):
         return zlib.crc32(value)
